@@ -49,6 +49,9 @@ class Controller:
         self.cache_matches = self.get_config(
             'cache_matches',
             default_value=1000)
+        self.cache_logs = self.get_config(
+            'cache_logs',
+            default_value=500)
         self.analyze_matches = self.get_config(
             'analyze_matches',
             default_value=100)
@@ -695,6 +698,18 @@ class Controller:
 
         return correct_player
 
+    def delete_old_logs(self):
+        """ Delete old logs in database."""
+        deletions = 0
+        for log_entry in self.db_session.query(model.Log).\
+                order_by(model.Log.datetime.desc()).\
+                offset(self.cache_logs).all():
+            self.db_session.delete(log_entry)
+            deletions += 1
+        if deletions > 0:
+            self.db_session.commit()
+            logger.info(f"{deletions} old log entries were deleted!")
+
     async def run(self):
         """Run the sc2monitor."""
         start_time = time.time()
@@ -721,10 +736,7 @@ class Controller:
                     'The following exception was'
                     f' raised while quering player {players[key].id}:')
 
-        if False:
-            for player in self.db_session.query(
-                    model.Player).all():
-                self.update_ema_mmr(player)
+        self.delete_old_logs()
 
         duration = time.time() - start_time
         self.db_session.add(
